@@ -1,3 +1,6 @@
+
+op = par(no.readonly = TRUE)
+
 library(circlize)
 factors = sample(letters[1:6], 100, replace = TRUE)
 x = rnorm(100)
@@ -28,4 +31,6 @@ circos.trackPlotRegion(factors = factors, x = x, y = y, bg.col = "#EEEEEE",
     circos.points(x[y > -1 & y < 1], y[y > -1 & y < 1], pch = 16, cex = 0.5)
 })
 
-circos.clear()
\ No newline at end of file
+circos.clear()
+
+par(op)
